@@ -8,6 +8,7 @@ import click
 from tqdm import tqdm
 
 from panoramic.cli.companies.client import CompaniesClient
+from panoramic.cli.config.analytics import is_enabled as analytics_module_is_enabled
 from panoramic.cli.config.storage import update_config
 from panoramic.cli.context import get_company_slug
 from panoramic.cli.controller import reconcile
@@ -46,13 +47,26 @@ from panoramic.cli.validate import (
 logger = logging.getLogger(__name__)
 
 
+def configure_anonymous_analytics():
+    if not analytics_module_is_enabled():
+        return
+
+    analytics_opt_out = click.confirm(
+        "\nDo you want to provide usage metrics to Panoramic?\n"
+        "No passwords,credentials, or personal information will be shared.",
+        default=True,
+    )
+    update_config('analytics', {'enabled': analytics_opt_out})
+
+
 def configure():
     """Global configuration for CLI."""
     client_id = click.prompt('Enter your client id', type=str)
     client_secret = click.prompt('Enter your client secret', hide_input=True, type=str)
-
     update_config('auth', {'client_id': client_id, 'client_secret': client_secret})
 
+    configure_anonymous_analytics()
+
 
 def initialize():
     """Initialize context."""
